🔸ALOS-2 PALSAR-2
==================


FBD L1.1 (``import_alos2_fbd_l11``)
------------------------------------

The `import_alos2_fbd_l11` function extracts C2 matrix elements from the given ALOS-2 FBD mode folder and saves them into a C2 directory.

.. autofunction:: polsartools.import_alos2_fbd_l11
   :noindex:


HBQ L1.1 (``import_alos2_hbq_l11``)
------------------------------------

The `import_alos2_hbq_l11` function extracts S2/T3/T4/C3/C4/C2/T2 matrix elements from the given ALOS-2 HBQ mode folder and saves them into a corresponding directories.

.. autofunction:: polsartools.import_alos2_hbq_l11
   :noindex:


WBD L1.1 (``import_alos2_wbd_l11``)
------------------------------------

The `import_alos2_wbd_l11` function extracts C2 matrix elements from the given ALOS-2 WBD mode folder (for any given swath) and saves them into a C2 directory.

.. autofunction:: polsartools.import_alos2_wbd_l11
   :noindex:
